Regenerate the logotext images using the src/crystal/util/generate_logotext.py
script, using instructions at the top of that script.

Logotext is prerendered into static graphics so that I don't need to purchase
a special "app" license to redistribute the font itself (Futura) used in the
logotext. At the time of writing, most "app" licenses require an annual fee,
which I am not willing to pay for this project.
